|pypi| |actions| |codecov| |downloads|

edc-qol
--------

Django classes for Quality of Life instruments.

Includes:

* EQ-5D-3L Instrument
* SF-12 Health Survey

See:

* https://euroqol.org/eq-5d-instruments/eq-5d-3l-about/

See also:

* https://github.com/clinicedc/edc
* https://github.com/meta-trial/meta-edc


|django|

.. |django| image:: https://www.djangoproject.com/m/img/badges/djangomade124x25.gif
   :target: http://www.djangoproject.com/
   :alt: Made with Django

.. |pypi| image:: https://img.shields.io/pypi/v/edc-qol.svg
    :target: https://pypi.python.org/pypi/edc-qol

.. |actions| image:: https://github.com/clinicedc/edc-qol/actions/workflows/build.yml/badge.svg
  :target: https://github.com/clinicedc/edc-qol/actions/workflows/build.yml

.. |codecov| image:: https://codecov.io/gh/clinicedc/edc-qol/branch/develop/graph/badge.svg
    :target: https://codecov.io/gh/clinicedc/edc-qol

.. |downloads| image:: https://pepy.tech/badge/edc-qol
    :target: https://pepy.tech/project/edc-qol
